// src/index.ts
import {alias as alias2} from "@stacksjs/alias";
import {kolorist as c} from "@stacksjs/cli";
import {docs as docs2} from "@stacksjs/config";
import {path as p} from "@stacksjs/path";
import {server as server2} from "@stacksjs/server";
import {withPwa} from "@vite-pwa/vitepress";
import {defineConfig} from "vitepress";
// package.json
var version = "0.63.0";

// src/scripts/pwa.ts
import {docs} from "@stacksjs/config";
import {frameworkPath} from "@stacksjs/path";

// src/meta.ts
var googleapis = "https://fonts.googleapis.com";
var gstatic = "https://fonts.gstatic.com";
var font = `${googleapis}/css2?family=Readex+Pro:wght@200;400;600&display=swap`;
var ogUrl = "https://stacksjs.org/";
var ogImage = `${ogUrl}og.png`;
var github = "https://github.com/stacksjs/stacks";
var releases = "https://github.com/stacksjs/stacks/releases";
var contributing = "https://github.com/stacksjs/stacks/blob/main/CONTRIBUTING.md";
var discord = "https://chat.stacksjs.org";
var twitter = "https://twitter.com/stacksjs";
var preconnectLinks = [googleapis, gstatic];
var preconnectHomeLinks = [googleapis, gstatic];
var pwaFontsRegex = new RegExp(`^${googleapis}/.*`, "i");
var pwaFontStylesRegex = new RegExp(`^${gstatic}/.*`, "i");
var githubusercontentRegex = /^https:\/\/((i.ibb.co)|((raw|user-images).githubusercontent.com))\/.*/i;

// src/scripts/pwa.ts
var pwaDocs = {
  outDir: frameworkPath("docs/dist"),
  registerType: "autoUpdate",
  manifest: {
    id: "/",
    name: docs.title,
    short_name: docs.title,
    description: docs.description,
    theme_color: "#ffffff",
    start_url: "/",
    lang: "en-US",
    dir: "ltr",
    orientation: "natural",
    display: "standalone",
    display_override: ["window-controls-overlay"],
    categories: ["development", "developer tools"],
    icons: [
      {
        src: "pwa-64x64.png",
        sizes: "64x64",
        type: "image/png"
      },
      {
        src: "pwa-192x192.png",
        sizes: "192x192",
        type: "image/png"
      },
      {
        src: "pwa-512x512.png",
        sizes: "512x512",
        type: "image/png",
        purpose: "any"
      },
      {
        src: "maskable-icon.png",
        sizes: "512x512",
        type: "image/png",
        purpose: "maskable"
      }
    ],
    screenshots: [
      {
        src: "og.png",
        sizes: "2258x1185",
        type: "image/png",
        label: `Screenshot of ${docs.title}`
      }
    ],
    handle_links: "preferred",
    launch_handler: {
      client_mode: ["navigate-existing", "auto"]
    },
    edge_side_panel: {
      preferred_width: 480
    }
  },
  workbox: {
    navigateFallbackDenylist: [/^\/new$/],
    maximumFileSizeToCacheInBytes: 3 * 1024 * 1024,
    globPatterns: ["**/*.{css,js,html,png,svg,ico,txt,woff2,json}"],
    dontCacheBustURLsMatching: /^assets\//,
    runtimeCaching: [
      {
        urlPattern: pwaFontsRegex,
        handler: "CacheFirst",
        options: {
          cacheName: "google-fonts-cache",
          expiration: {
            maxEntries: 10,
            maxAgeSeconds: 60 * 60 * 24 * 365
          },
          cacheableResponse: {
            statuses: [0, 200]
          }
        }
      },
      {
        urlPattern: pwaFontStylesRegex,
        handler: "CacheFirst",
        options: {
          cacheName: "gstatic-fonts-cache",
          expiration: {
            maxEntries: 10,
            maxAgeSeconds: 60 * 60 * 24 * 365
          },
          cacheableResponse: {
            statuses: [0, 200]
          }
        }
      },
      {
        urlPattern: githubusercontentRegex,
        handler: "CacheFirst",
        options: {
          cacheName: "githubusercontent-images-cache",
          expiration: {
            maxEntries: 10,
            maxAgeSeconds: 60 * 60 * 24 * 365
          },
          cacheableResponse: {
            statuses: [0, 200]
          }
        }
      }
    ]
  },
  experimental: {
    includeAllowlist: true
  }
};

// src/plugins.ts
import {transformerTwoslash} from "vitepress-plugin-twoslash";
import TwoSlashFloatingVue from "vitepress-plugin-twoslash/client";

// src/index.ts
var frameworkDefaults = {
  base: "/docs/",
  cleanUrls: true,
  srcDir: p.projectPath("docs"),
  outDir: p.projectStoragePath("framework/docs"),
  cacheDir: p.projectStoragePath("framework/cache/docs"),
  assetsDir: p.assetsPath(),
  vite: {
    envDir: p.projectPath(),
    envPrefix: "FRONTEND_",
    server: server2({
      type: "docs"
    }),
    resolve: {
      alias: alias2
    },
    plugins: [
      {
        name: "stacks-plugin",
        configureServer(server3) {
          server3.printUrls = () => {
            console.log(`  ${c.blue(c.bold("STACKS"))} ${c.blue(version)}`);
            console.log(`  ${c.green("\u279C")}  ${c.bold("Docs")}: ${c.green("https://stacks.localhost/docs")}`);
            console.log(`  ${c.green("\u279C")}  ${c.bold("Temp URL")}: ${c.green("http://stacksjs.test:3000")}`);
          };
        }
      }
    ]
  },
  pwa: pwaDocs
};
var config3 = {
  ...frameworkDefaults,
  ...docs2
};
var src_default = withPwa(defineConfig(config3));
export {
  twitter,
  transformerTwoslash,
  releases,
  pwaFontsRegex,
  pwaFontStylesRegex,
  pwaDocs,
  preconnectLinks,
  preconnectHomeLinks,
  ogUrl,
  ogImage,
  gstatic,
  googleapis,
  githubusercontentRegex,
  github,
  frameworkDefaults,
  font,
  discord,
  src_default as default,
  contributing,
  TwoSlashFloatingVue
};

//# debugId=3900EE4EA64EB65B64756E2164756E21
//# sourceMappingURL=index.js.map
